@@ -36,7 +36,7 @@ class DocumentRetrievalFactory:
         connection = DocumentRetrievalFactory._get_matching_connection(key.datasource, key.cluster, application.conn_details)
         try:
             platform = connection['platform']
-            if platform == 'COS':
+            if platform == 'IBM COS':
                 _, client, connection = application.create_cos_connection(connection)
                 return DocumentRetrievalCOS(client, connection)
             elif platform == 'NFS':
@@ -50,7 +50,7 @@ class DocumentRetrievalFactory:
             elif platform == 'SMB/CIFS':
                 _, client, connection = application.create_smb_connection(connection, key.fileset)
                 return DocumentRetrievalSMB(client, connection)
-        except KeyError:
+        except (TypeError, KeyError):
             # No connection found
             pass
         return None
@@ -283,12 +283,16 @@ class DocumentRetrievalScale(DocumentRetrievalBase):
             try:
                 self.filepath = self.create_file_path('/tmp/scalefile_' + str(os.getpid()), self.key.filetype)
                 self.client.get(self.key.path, self.filepath)
-            except UnicodeDecodeError:
-                self.logger.error('Could not decode file %s', self.key.path.decode(ENCODING))
-            except FileNotFoundError:
-                self.logger.error('Could not find file %s', self.key.path.decode(ENCODING))
-            except OSError:  # Seen when scale nsd disk is down and file is not accessible
-                self.logger.error('Could not transfer file %s', self.key.path.decode(ENCODING))
+            except (UnicodeDecodeError, FileNotFoundError, OSError) as error:
+                if isinstance(error, UnicodeDecodeError):
+                    self.logger.error('Could not decode file %s', self.key.path.decode(ENCODING))
+                elif isinstance(error, FileNotFoundError):
+                    self.logger.error('Could not find file %s', self.key.path.decode(ENCODING))
+                elif isinstance(error, OSError):  # Seen when scale nsd disk is down and file is not accessible
+                    self.logger.error('Could not transfer file %s', self.key.path.decode(ENCODING))
+                # On an error, paramiko will create an empty file that needs to be cleaned up.
+                self.cleanup_document()
+                self.filepath = None
 
         else:
             self.logger.info('No document match')
@@ -389,10 +393,8 @@ class DocumentKey(object):
         self.datasource = doc['datasource']
         self.cluster = doc['cluster']
         self.path = doc['path'].encode(ENCODING)
-        if 'type' in doc.keys():  # deepinspect
-            self.filetype = doc['type']
-        if 'fileset' in doc.keys(): # 2.0.3+
-            self.fileset = doc['fileset']
+        self.filetype = doc['type'] if 'type' in doc.keys() else None  # deepinspect
+        self.fileset = doc['fileset'] if 'fileset' in doc.keys() else None  # 2.0.3.1+
         # a unique identifier for the connection this document belongs to.
         self.id = self.datasource + ':' + self.cluster
 
